Index: gw/smsc/smsc_soap.c
===================================================================
RCS file: /home/cvs/gateway/gw/smsc/smsc_soap.c,v
retrieving revision 1.20
diff -u -r1.20 smsc_soap.c
--- gw/smsc/smsc_soap.c	10 Mar 2008 09:37:42 -0000	1.20
+++ gw/smsc/smsc_soap.c	21 Jul 2008 12:05:18 -0000
@@ -223,7 +223,7 @@
 /* useful macros go here (some of these were ripped of other modules,
    so maybe its better to put them in a shared file) */
 #define	O_DESTROY(a)	{ if(a) octstr_destroy(a); a=NULL; }
-typedef long long int64;
+typedef long long gw_int64;
  
 /*
  * SOAP module public API towards bearerbox
@@ -265,7 +265,7 @@
 static Octstr *soap_format_xml(Octstr *xml_file, Msg *msg, PrivData *privdata);
 /* parse a response from the SOAP server to get the message ID */
 
-static int64 soap_parse_response(PrivData *privdata, Octstr *xmlResponse);
+static gw_int64 soap_parse_response(PrivData *privdata, Octstr *xmlResponse);
 /* parse an incoming MO xml */
 static long soap_parse_mo(SMSCConn *conn, Octstr *request, Octstr **response);
 /* parse an incoming derlivery report */
@@ -276,8 +276,8 @@
  */
 /* parse an integer out of a XML node */
 int soap_xmlnode_get_long(xmlNodePtr cur, long *out);
-/* parse an int64 out of a XML node */
-int soap_xmlnode_get_int64(xmlNodePtr cur, int64 *out);
+/* parse an gw_int64 out of a XML node */
+int soap_xmlnode_get_int64(xmlNodePtr cur, gw_int64 *out);
 /* parse a string out of a XML node */
 int soap_xmlnode_get_octstr(xmlNodePtr cur, Octstr **out);
 /* convert a one2one date format to epoch time */
@@ -1123,7 +1123,7 @@
     Octstr *responseBody, *responseURL;
     List* responseHeaders;
     int responseStatus;
-    int64 msgID;
+    gw_int64 msgID;
     ClientData* cd;
 
     /* don't get in here unless I have some callers */
@@ -1203,9 +1203,9 @@
  *                but if gwlist_get() returns NULL for an empty item, things might break - and
  *                not in a nice way.
  **/
-static int64 soap_parse_response(PrivData* privdata, Octstr* xmlResponse)
+static gw_int64 soap_parse_response(PrivData* privdata, Octstr* xmlResponse)
 {
-    int64 msgID = -1;
+    gw_int64 msgID = -1;
     long responseStatus = -1;
     xmlDocPtr responseDoc;
     xmlNodePtr root;
@@ -1286,7 +1286,7 @@
 
     List* maps;
     char receiver[30], sender[30], msgtype[30], msgdata[255], date[30];
-    int64 msgid = -1;
+    gw_int64 msgid = -1;
     char* keywords[] = { "receiver", "sender", "msgtype", "msgdata", "date", "id" };
     char* sscans[] = { "%s", "%s", "%s", "%s", "%s", "%lld" };
     void* pointers[] = { &receiver, &sender, &msgtype, &msgdata, &date, &msgid };
@@ -1705,12 +1705,12 @@
 
 /*
  * function soap_xmlnode_get_int64()
  *	parse the content of an XML node and return it as an int64
  * Input: xmlNodePtr to node
  * Output: long parsed
  * Returns: 0 on success, -1 on failure
  **/
-int soap_xmlnode_get_int64(xmlNodePtr cur, int64* out)
+int soap_xmlnode_get_int64(xmlNodePtr cur, gw_int64* out)
 {
     xmlChar* nodeContent;
     char* endPointer;
@@ -1705,12 +1705,12 @@
 /*
  * function soap_xmlnode_get_int64()
- *	parse the content of an XML node and return it as an int64
+ *	parse the content of an XML node and return it as an gw_int64
  * Input: xmlNodePtr to node
  * Output: long parsed
